==> mathjax_2.3.orig.tar.gz: MathJax-2.3/unpacked/localization/sv/MathMenu.js <==
/* -*- Mode: Javascript; indent-tabs-mode:nil; js-indent-level: 2 -*- */
/* vim: set ts=2 et sw=2 tw=80: */

/*************************************************************
 *
 *  MathJax/localization/sv/MathMenu.js
 *
 *  Copyright (c) 2009-2013 The MathJax Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */

MathJax.Localization.addTranslation("sv","MathMenu",{
        version: "2.3",
        isLoaded: true,
        strings: {
          MathMLcode: "MathML-kod",
          OriginalMathML: "Ursprunglig MathML",
          TeXCommands: "TeX-kommandon",
          AsciiMathInput: "AsciiMathML-inmatning",
          Original: "Ursprungligt format",
          ErrorMessage: "Felmeddelande",
          TeX: "TeX",
          StarMath: "StarMath",
          OpenMath: "OpenMath",
          Click: "Klick",
          DoubleClick: "Dubbelklick",
          NoZoom: "Ingen zoom",
          Option: "Alternativ",
          Alt: "Alt",
          Command: "Command",
          Control: "Ctrl",
          Shift: "Shift",
          TeXLocal: "TeX (lokal)",
          TeXWeb: "TeX (webb)",
          TeXImage: "TeX (bild)",
          STIXLocal: "STIX (lokal)",
          Locale: "Spr\u00E5k",
          LoadLocale: "L\u00E4s in fr\u00E5n URL ...",
          About: "Om MathJax",
          Help: "Hj\u00E4lp f\u00F6r MathJax",
          eotffonts: "eot-teckensnitt",
          svgfonts: "svg-teckensnitt",
          Close: "St\u00E4ng"
        }
});

MathJax.Ajax.loadComplete("[MathJax]/localization/sv/MathMenu.js");

==> mathjax_2.4.orig.tar.gz: MathJax-2.4/unpacked/localization/sv/MathMenu.js <==
/* -*- Mode: Javascript; indent-tabs-mode:nil; js-indent-level: 2 -*- */
/* vim: set ts=2 et sw=2 tw=80: */

/*************************************************************
 *
 *  MathJax/localization/sv/MathMenu.js
 *
 *  Copyright (c) 2009-2014 The MathJax Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */

MathJax.Localization.addTranslation("sv","MathMenu",{
        version: "2.4.0",
        isLoaded: true,
        strings: {
          MathMLcode: "MathML-kod",
          OriginalMathML: "Ursprunglig MathML",
          TeXCommands: "TeX-kommandon",
          AsciiMathInput: "AsciiMathML-inmatning",
          Original: "Ursprungligt format",
          ErrorMessage: "Felmeddelande",
          TeX: "TeX",
          StarMath: "StarMath",
          OpenMath: "OpenMath",
          Click: "Klick",
          DoubleClick: "Dubbelklick",
          NoZoom: "Ingen zoom",
          Option: "Alternativ",
          Alt: "Alt",
          Command: "Command",
          Control: "Ctrl",
          Shift: "Shift",
          MenuEvents: "Menyh\u00E4ndelser",
          MouseEvents: "Mush\u00E4ndelser",
          MenuAndMouse: "Mus- och menyh\u00E4ndelser",
          FontPrefs: "Teckensnittsinst\u00E4llningar",
          ForHTMLCSS: "F\u00F6r HTML-CSS:",
          Auto: "Auto",
          TeXLocal: "TeX (lokal)",
          TeXWeb: "TeX (webb)",
          TeXImage: "TeX (bild)",
          STIXLocal: "STIX (lokal)",
          STIXWeb: "STIX (webb)",
          AsanaMathWeb: "Asana Math (webb)",
          GyrePagellaWeb: "Gyre Pagella (webb)",
          GyreTermesWeb: "Gyre Termes (webb)",
          LatinModernWeb: "Latin Modern (webb)",
          NeoEulerWeb: "Neo Euler (webb)",
          Browser: "Webbl\u00E4sare",
          Discoverable: "Markera vid hovring",
          Locale: "Spr\u00E5k",
          LoadLocale: "L\u00E4s in fr\u00E5n URL ...",
          About: "Om MathJax",
          Help: "Hj\u00E4lp f\u00F6r MathJax",
          eotffonts: "eot-teckensnitt",
          svgfonts: "svg-teckensnitt",
          MSIENativeMMLWarning: "Internet Explorer kr\u00E4ver insticksmodulen MathPlayer f\u00F6r att kunna bearbeta utmatning f\u00F6r MathML.",
          NonZeroScale: "Skalan b\u00F6r inte vara noll",
          PercentScale: "Skalan b\u00F6r vara en procentsats (t.ex. 120%%)",
          Close: "St\u00E4ng"
        }
});

MathJax.Ajax.loadComplete("[MathJax]/localization/sv/MathMenu.js");
